contrib — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »
- API Reference »

# contrib

## boto.contrib

## boto.contrib.ymlmessage

This module was contributed by Chris Moyer. It provides a subclass of the SQS Message class that supports YAML as the body of the message.

This module requires the yaml module.

class `boto.contrib.ymlmessage.` `YAMLMessage`(queue=None, body='', xml_attrs=None)

  The YAMLMessage class provides a YAML compatible message. Encoding and decoding are handled automaticaly.

  Access this message data like such:

  m.data = [ 1, 2, 3] m.data[0] # Returns 1

  This depends on the PyYAML package

  `get_body`()
  `set_body`(body)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »
- API Reference »